% gauss_filter: Obtains a smoothed gaussian filter image
%   - Output:  
%       smooth: image filter by a gaussian filter
%   - Input:
%       image:  Matrix containing single band image.
%       sigma:  Value of the sigma for the Gaussian filter
%       kernel_size: Size of the gaussian kernel (default: 6*sigma)
function [smooth]= gauss_filter(image,sigma,kernel_size)
if nargin < 2
    sigma=1;    
end
if nargin < 3
    kernel_size=6*sigma;
end
gaussian_radio=floor(kernel_size/2);  %radio of the gaussian
x=[-gaussian_radio : gaussian_radio];   % x values (gaussian kernel size)
gaussiano= exp(-x.^2/(2*sigma^2))/(sigma*sqrt(2*pi) );   %calculate the unidimensional gaussian 
temp=conv2(double(image),double(gaussiano),'same');
smooth=conv2(double(temp),double(gaussiano'),'same');
end
